@@ -12,6 +12,7 @@ MAX_PENDING = 10
 
 class Listener(object):
 	def __init__(self):
+		self.loop = asyncio.get_event_loop()
 		self.aevent = asyncio.Event()
 		self.user_id = ''
 		self.channels = set()
@@ -19,6 +20,9 @@ class Listener(object):
 		self.overflow = False
 		self.error = ''
 
+	def wake_threadsafe(self):
+		self.loop.call_soon_threadsafe(self.aevent.set)
+
 class ListenerManager(object):
 	def __init__(self):
 		self.lock = threading.Lock()
@@ -63,7 +67,7 @@ class ListenerManager(object):
 				else:
 					l.overflow = True
 			for l in wake:
-				l.aevent.set()
+				l.wake_threadsafe()
 		finally:
 			self.lock.release()
 
@@ -78,7 +82,7 @@ class ListenerManager(object):
 					l.error = {'condition': 'forbidden', 'text': msg, 'channels': [channel]}
 					wake.append(l)
 			for l in wake:
-				l.aevent.set()
+				l.wake_threadsafe()
 		finally:
 			self.lock.release()
 
@@ -134,7 +138,10 @@ class EventsConsumer(AsyncHttpConsumer):
 
 		request = AsgiRequest(self.scope, body)
 
-		gm = GripMiddleware()
+		def dummy_get_response(request):
+			return None
+
+		gm = GripMiddleware(dummy_get_response)
 		gm.process_request(request)
 
 		if 'user' in self.scope:
